@@ -13,6 +13,7 @@ import tempfile
 from pytorch_lightning import Callback
 from deepforest import dataset
 from deepforest import utilities
+from deepforest import predict
 
 import torch
 
@@ -49,16 +50,15 @@ class images_callback(Callback):
         self.csv_file = "{}/image_callback.csv".format(savedir)        
         self.every_n_epochs = every_n_epochs
          
-
     def log_images(self, pl_module):
-        boxes = pl_module.predict_file(self.csv_file, self.root_dir, savedir=self.savedir)
+        boxes = predict.predict_file(model = pl_module.model, csv_file=self.csv_file, root_dir=self.root_dir, savedir=self.savedir, device=pl_module.device)
         try:
             saved_plots = glob.glob("{}/*.png".format(self.savedir))
             for x in saved_plots:
                 pl_module.logger.experiment.log_image(x)
         except Exception as e:
             print(
-                "Could not find logger in ligthning module, skipping upload, images were saved to {}, error was rasied {}"
+                "Could not find logger in lightning module, skipping upload, images were saved to {}, error was rasied {}"
                 .format(self.savedir, e))
 
     def on_epoch_end(self, trainer, pl_module):
